==> jammo_0.6.10.tar.gz: jammo-0.6.10/src/chum/pen_gesture/createALLknots.c <==
#include <stdlib.h>
#include <gmodule.h>
#include <tangle.h>
#include "createALLknots.h"

//Make it an object - maybe be done
/*
typedef struct {
	ClutterActor *act;
	int height;
	int width;
	int x_pos;
	int y_pos;

} myKnote;
*/


ClutterActor *create_knot_with_pos(ClutterActor *stage, gint pos_x, gint pos_y)
{

	ClutterColor *knot_color;
	//knot_color = clutter_color_new(0xFC,0x5E,0xD5,224);
	//knot_color = clutter_color_new(0xA5,0xA5,0xA5,224);
	knot_color = clutter_color_new(0xF8,0xFF,0x5B,224);
	//Random colors for every knot / Disabled for speed
	/*knot_color = clutter_color_new (g_random_int_range (0, 255),
	                             g_random_int_range (0, 255),
	                             g_random_int_range (0, 255),
	                             224);
	*/

	ClutterActor *knot = clutter_rectangle_new_with_color (knot_color);
	clutter_actor_set_size (knot, 40, 40);
	clutter_actor_set_position (knot, pos_x, pos_y);
	clutter_container_add_actor (CLUTTER_CONTAINER (stage), knot);
	clutter_actor_show (knot);
	clutter_actor_set_opacity(knot, 0);
	clutter_actor_set_reactive (knot, TRUE);
	return knot;
}


//The nine points
ClutterActor *create_points_with_pos(ClutterActor *stage, gint pos_x, gint pos_y)
{
	  gchar* directory_path1 ="/opt/jammo/password/";
	  gchar* filename1="sphere.png";
	  gchar* path1 = g_build_filename (directory_path1, filename1, NULL);
	  ClutterActor *point = clutter_texture_new_from_file (path1, NULL);
	  clutter_actor_set_size (point, 60, 60);
	  clutter_actor_set_position (point, pos_x, pos_y);
	  //clutter_actor_set_opacity(rect,10);
	  clutter_actor_show (point);
	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), point);
	  //clutter_actor_set_name(point,"xoxo");
	  clutter_actor_set_reactive (point, TRUE);
	  //return EXIT_SUCCESS;
	  return point;
}

==> jammo_0.6.13.tar.gz: jammo-0.6.13/src/chum/pen_gesture/createALLknots.c <==
#include <stdlib.h>
#include <gmodule.h>
#include <tangle.h>
#include "createALLknots.h"

//Make it an object - maybe be done
/*
typedef struct {
	ClutterActor *act;
	int height;
	int width;
	int x_pos;
	int y_pos;

} myKnote;
*/


ClutterActor *create_knot_with_pos(ClutterActor *stage, gint pos_x, gint pos_y)
{

	ClutterColor *knot_color;
	knot_color = clutter_color_new(0xFC,0x5E,0xD5,224);
	//knot_color = clutter_color_new(0xA5,0xA5,0xA5,224);
	//knot_color = clutter_color_new(0xF8,0xFF,0x5B,224);
	//Random colors for every knot / Disabled for speed
	/*knot_color = clutter_color_new (g_random_int_range (0, 255),
	                             g_random_int_range (0, 255),
	                             g_random_int_range (0, 255),
	                             224);
	*/

	ClutterActor *knot = clutter_rectangle_new_with_color (knot_color);
	clutter_actor_set_size (knot, 40, 40);
	clutter_actor_set_position (knot, pos_x, pos_y);
	clutter_container_add_actor (CLUTTER_CONTAINER (stage), knot);
	clutter_actor_show (knot);
	clutter_actor_set_opacity(knot, 0);
	clutter_actor_set_reactive (knot, TRUE);
	return knot;
}


//The nine points
ClutterActor *create_points_with_pos(ClutterActor *stage, gint pos_x, gint pos_y)
{
	  gchar* directory_path1 ="/opt/jammo/password/";
	  gchar* filename1="sphere.png";
	  gchar* path1 = g_build_filename (directory_path1, filename1, NULL);
	  ClutterActor *point = clutter_texture_new_from_file (path1, NULL);
	  clutter_actor_set_size (point, 60, 60);
	  clutter_actor_set_position (point, pos_x, pos_y);
	  //clutter_actor_set_opacity(rect,10);
	  clutter_actor_show (point);
	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), point);
	  //clutter_actor_set_name(point,"xoxo");
	  clutter_actor_set_reactive (point, TRUE);
	  //return EXIT_SUCCESS;
	  return point;
}
